$.i18n().load({
    "en": {
        "nimgame_restart_buttnon": "Restart",
        "nimgame_take": "Take",
        "nimgame_single_player": "Single player",
        "nimgame_error": "You can take up to $1",
        "nimgame_winner" : "Player $1 won.",
        "nimgame_alg_won" : "Computer won.",
        "nimgame_take_away_msg" : "you can take between <span>1</span> and <span>$1</span>"
    }
})